cgexplore.forcefields.ForceField
================================

.. currentmodule:: cgexplore.forcefields

.. autoclass:: ForceField
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~ForceField.assign_terms
      ~ForceField.get_all_possible_terms
      ~ForceField.get_bead_library
      ~ForceField.get_hr_file_name
      ~ForceField.get_identifier
      ~ForceField.get_prefix
      ~ForceField.get_present_beads
      ~ForceField.get_targets
      ~ForceField.get_vdw_bond_cutoff
      ~ForceField.write_human_readable
   
   

   
   
   